@@ -171,7 +171,7 @@ main (gint argc, gchar *argv[])
       de_data_simple.H_id == NULL &&
       de_data_simple.cluster_id == NULL)
   {
-    printf ("No action or data was chosen.\n");
+    printf ("No action or data were chosen.\n");
     printf ("%s", g_option_context_get_help (context, TRUE, NULL));
     g_option_context_free (context);
     return 0;
@@ -214,30 +214,41 @@ main (gint argc, gchar *argv[])
   {
     ncm_prior_add_positive (lh, NC_HICOSMO_ID, NC_HICOSMO_DE_OMEGA_X);
   }
-
+  
   if (de_data_simple.snia_id != NULL)
   {
-    const GEnumValue *snia_id = ncm_cfg_get_enum_by_id_name_nick (NC_TYPE_DATA_DIST_MU_ID,
-                                                                  de_data_simple.snia_id);
-    if (snia_id != NULL)
+    const GEnumValue *snia_id = 
+      ncm_cfg_get_enum_by_id_name_nick (NC_TYPE_DATA_SNIA_ID,
+                                        de_data_simple.snia_id);
+    if (snia_id == NULL)
+      g_error ("Supernovae sample '%s' not found run --snia-list to list"
+               " the available options", de_data_simple.snia_id);
+
+    if (snia_id->value >= NC_DATA_SNIA_SIMPLE_START && snia_id->value <= NC_DATA_SNIA_SIMPLE_END)
     {
       NcmData *snia = nc_data_dist_mu_new (dist, snia_id->value);
       ncm_dataset_append_data (dset, snia);
       ncm_data_free (snia);
     }
+    else if (snia_id->value >= NC_DATA_SNIA_COV_START && snia_id->value <= NC_DATA_SNIA_COV_END)
+    {
+      NcSNIADistCov *dcov = nc_snia_dist_cov_new (dist, 0);
+      NcmData *data;
+
+      if (de_data_simple.snia_prop != NULL)
+        ncm_cfg_object_set_property (G_OBJECT (dcov), de_data_simple.snia_prop);
+
+      nc_data_snia_load_cat (dcov, snia_id->value);
+      data = nc_data_snia_cov_new (dcov, de_data_simple.snia_use_det);
+      ncm_mset_set (mset, NCM_MODEL (dcov));
+      ncm_dataset_append_data (dset, data);
+      ncm_data_free (data);
+    }
     else
-      g_error ("Supernovae sample '%s' not found run --snia-list to list the available options", de_data_simple.snia_id);
+      g_assert_not_reached ();
   }
 
-  if (TRUE)
-  {
-    NcSNIADistCov *dcov = nc_snia_dist_cov_new (0);
-    nc_snia_dist_cov_load (dcov, "test_dcov.ini");
-
-  }
-
-
-  
+ 
   if (de_data_simple.cmb_id != NULL)
   {
     const GEnumValue *cmb_id = ncm_cfg_get_enum_by_id_name_nick (NC_TYPE_DATA_CMB_ID,
@@ -302,7 +313,7 @@ main (gint argc, gchar *argv[])
 
     ncm_prior_add_gaussian_data (lh, NC_HICOSMO_ID, NC_HICOSMO_DE_H0, 73.8, 2.4);
   }
-
+  
   fiduc = ncm_mset_dup (mset);
 
   {
@@ -324,6 +335,7 @@ main (gint argc, gchar *argv[])
   {
     fit->params_reltol = 1e-5;
     ncm_fit_run (fit, de_fit.msg_level);
+    
     ncm_fit_log_info (fit);
   }
 
@@ -415,7 +427,7 @@ main (gint argc, gchar *argv[])
       }
       {
         NcmMSetPIndex pi = {NC_HICOSMO_ID, p_n};
-        NcmLHRatio1d *lhr1d = ncm_lh_ratio1d_new (fit, pi);
+        NcmLHRatio1d *lhr1d = ncm_lh_ratio1d_new (fit, &pi);
         ncm_lh_ratio1d_find_bounds (lhr1d, fit->mtype, prob_sigma, &err_inf, &err_sup);
         ncm_lh_ratio1d_free (lhr1d);
       }
@@ -441,37 +453,34 @@ main (gint argc, gchar *argv[])
     NcmLHRatio2d *lhr2d;
     NcmMSetPIndex pi1;
     NcmMSetPIndex pi2;
-    GList *points_1sigma;
-    GList *points_2sigma;
-    GList *points_3sigma;
+    NcmLHRatio2dRegion *rg_1sigma = NULL;
+    NcmLHRatio2dRegion *rg_2sigma = NULL;
+    NcmLHRatio2dRegion *rg_3sigma = NULL;
 
     pi1.mid = NC_HICOSMO_ID;
     pi2.mid = NC_HICOSMO_ID;
     pi1.pid = de_fit.bidim_cr[0];
     pi2.pid = de_fit.bidim_cr[1];
 
-    lhr2d = ncm_lh_ratio2d_new (fit, pi1, pi2);
+    lhr2d = ncm_lh_ratio2d_new (fit, &pi1, &pi2);
     
-    points_1sigma = NULL;
-    points_2sigma = NULL;
-    points_3sigma = NULL;
     switch (de_fit.nsigma)
     {
       case 1:
       {
-        points_1sigma = ncm_lh_ratio2d_conf_region (lhr2d, ncm_c_stats_1sigma (), de_fit.msg_level);
+        rg_1sigma = ncm_lh_ratio2d_conf_region (lhr2d, ncm_c_stats_1sigma (), 0.0, de_fit.msg_level);
         break;
       }
       case 2:
-        points_2sigma = ncm_lh_ratio2d_conf_region (lhr2d, ncm_c_stats_2sigma (), de_fit.msg_level);
+        rg_2sigma = ncm_lh_ratio2d_conf_region (lhr2d, ncm_c_stats_2sigma (), 0.0, de_fit.msg_level);
         break;
       case 3:
-        points_3sigma = ncm_lh_ratio2d_conf_region (lhr2d, ncm_c_stats_3sigma (), de_fit.msg_level);
+        rg_3sigma = ncm_lh_ratio2d_conf_region (lhr2d, ncm_c_stats_3sigma (), 0.0, de_fit.msg_level);
         break;
       default:
-        points_1sigma = ncm_lh_ratio2d_conf_region (lhr2d, ncm_c_stats_1sigma (), de_fit.msg_level);
-        points_2sigma = ncm_lh_ratio2d_conf_region (lhr2d, ncm_c_stats_2sigma (), de_fit.msg_level);
-        points_3sigma = ncm_lh_ratio2d_conf_region (lhr2d, ncm_c_stats_3sigma (), de_fit.msg_level);
+        rg_1sigma = ncm_lh_ratio2d_conf_region (lhr2d, ncm_c_stats_1sigma (), 0.0, de_fit.msg_level);
+        rg_2sigma = ncm_lh_ratio2d_conf_region (lhr2d, ncm_c_stats_2sigma (), 0.0, de_fit.msg_level);
+        rg_3sigma = ncm_lh_ratio2d_conf_region (lhr2d, ncm_c_stats_3sigma (), 0.0, de_fit.msg_level);
         break;
     }
 
@@ -482,19 +491,19 @@ main (gint argc, gchar *argv[])
       f_PL = nc_de_open_dataout_file (model, "PL", &pfile);
 
       fprintf (f_PL, "# %s\n", full_cmd_line);
-      if (points_1sigma != NULL)
+      if (rg_1sigma != NULL)
       {
-       ncm_lh_ratio2d_points_print (points_1sigma, f_PL);
+       ncm_lh_ratio2d_region_print (rg_1sigma, f_PL);
         fprintf (f_PL, "\n\n");
       }
-      if (points_2sigma != NULL)
+      if (rg_2sigma != NULL)
       {
-        ncm_lh_ratio2d_points_print (points_2sigma, f_PL);
+        ncm_lh_ratio2d_region_print (rg_2sigma, f_PL);
         fprintf (f_PL, "\n\n");
       }
-      if (points_3sigma != NULL)
+      if (rg_3sigma != NULL)
       {
-        ncm_lh_ratio2d_points_print (points_3sigma, f_PL);
+        ncm_lh_ratio2d_region_print (rg_3sigma, f_PL);
         fprintf (f_PL, "\n\n");
       }
 
@@ -504,9 +513,9 @@ main (gint argc, gchar *argv[])
 
       g_free (pfile);
     }
-    ncm_lh_ratio2d_points_free (points_1sigma);
-    ncm_lh_ratio2d_points_free (points_2sigma);
-    ncm_lh_ratio2d_points_free (points_3sigma);
+    ncm_lh_ratio2d_region_clear (&rg_1sigma);
+    ncm_lh_ratio2d_region_clear (&rg_2sigma);
+    ncm_lh_ratio2d_region_clear (&rg_3sigma);
     ncm_lh_ratio2d_free (lhr2d);
   }
 
@@ -515,36 +524,32 @@ main (gint argc, gchar *argv[])
     NcmLHRatio2d *lhr2d;
     NcmMSetPIndex pi1;
     NcmMSetPIndex pi2;
-    GList *points_1sigma;
-    GList *points_2sigma;
-    GList *points_3sigma;
+    NcmLHRatio2dRegion *rg_1sigma = NULL;
+    NcmLHRatio2dRegion *rg_2sigma = NULL;
+    NcmLHRatio2dRegion *rg_3sigma = NULL;
 
     pi1.mid = NC_HICOSMO_ID;
     pi2.mid = NC_HICOSMO_ID;
     pi1.pid = de_fit.bidim_cr[0];
     pi2.pid = de_fit.bidim_cr[1];
 
-    lhr2d = ncm_lh_ratio2d_new (fit, pi1, pi2);
-    
-    points_1sigma = NULL;
-    points_2sigma = NULL;
-    points_3sigma = NULL;
+    lhr2d = ncm_lh_ratio2d_new (fit, &pi1, &pi2);
 
     switch (de_fit.nsigma_fisher)
     {
       case 1:
-        points_1sigma = ncm_lh_ratio2d_fisher_border (lhr2d, ncm_c_stats_1sigma (), de_fit.msg_level);
+        rg_1sigma = ncm_lh_ratio2d_fisher_border (lhr2d, ncm_c_stats_1sigma (), 0.0, de_fit.msg_level);
         break;
       case 2:
-        points_2sigma = ncm_lh_ratio2d_fisher_border (lhr2d, ncm_c_stats_2sigma (), de_fit.msg_level);
+        rg_2sigma = ncm_lh_ratio2d_fisher_border (lhr2d, ncm_c_stats_2sigma (), 0.0, de_fit.msg_level);
         break;
       case 3:
-        points_3sigma = ncm_lh_ratio2d_fisher_border (lhr2d, ncm_c_stats_3sigma (), de_fit.msg_level);
+        rg_3sigma = ncm_lh_ratio2d_fisher_border (lhr2d, ncm_c_stats_3sigma (), 0.0, de_fit.msg_level);
         break;
       default:
-        points_1sigma = ncm_lh_ratio2d_fisher_border (lhr2d, ncm_c_stats_1sigma (), de_fit.msg_level);
-        points_2sigma = ncm_lh_ratio2d_fisher_border (lhr2d, ncm_c_stats_2sigma (), de_fit.msg_level);
-        points_3sigma = ncm_lh_ratio2d_fisher_border (lhr2d, ncm_c_stats_3sigma (), de_fit.msg_level);
+        rg_1sigma = ncm_lh_ratio2d_fisher_border (lhr2d, ncm_c_stats_1sigma (), 0.0, de_fit.msg_level);
+        rg_2sigma = ncm_lh_ratio2d_fisher_border (lhr2d, ncm_c_stats_2sigma (), 0.0, de_fit.msg_level);
+        rg_3sigma = ncm_lh_ratio2d_fisher_border (lhr2d, ncm_c_stats_3sigma (), 0.0, de_fit.msg_level);
         break;
     }
 
@@ -555,19 +560,19 @@ main (gint argc, gchar *argv[])
       f_MFcr = nc_de_open_dataout_file (model, "MF_cr", &mcrfile);
 
       fprintf (f_MFcr, "# %s\n", full_cmd_line);
-      if (points_1sigma != NULL)
+      if (rg_1sigma != NULL)
       {
-        ncm_lh_ratio2d_points_print (points_1sigma, f_MFcr);
+        ncm_lh_ratio2d_region_print (rg_1sigma, f_MFcr);
         fprintf (f_MFcr, "\n\n");
       }
-      if (points_2sigma != NULL)
+      if (rg_2sigma != NULL)
       {
-        ncm_lh_ratio2d_points_print (points_2sigma, f_MFcr);
+        ncm_lh_ratio2d_region_print (rg_2sigma, f_MFcr);
         fprintf (f_MFcr, "\n\n");
       }
-      if (points_3sigma != NULL)
+      if (rg_3sigma != NULL)
       {
-        ncm_lh_ratio2d_points_print (points_3sigma, f_MFcr);
+        ncm_lh_ratio2d_region_print (rg_3sigma, f_MFcr);
         fprintf (f_MFcr, "\n\n");
       }
 
@@ -578,9 +583,9 @@ main (gint argc, gchar *argv[])
       g_free (mcrfile);
     }
 
-    ncm_lh_ratio2d_points_free (points_1sigma);
-    ncm_lh_ratio2d_points_free (points_2sigma);
-    ncm_lh_ratio2d_points_free (points_3sigma);
+    ncm_lh_ratio2d_region_clear (&rg_1sigma);
+    ncm_lh_ratio2d_region_clear (&rg_2sigma);
+    ncm_lh_ratio2d_region_clear (&rg_3sigma);
   }
 
   if (de_data_cluster.print_mass_function == TRUE && ca_array != NULL)
@@ -593,7 +598,7 @@ main (gint argc, gchar *argv[])
     for (i = 0; i < ca_array->len; i++)
     {
       NcmData *dca_unbinned = g_ptr_array_index (ca_array, i);
-      nc_mass_function_print (dca_unbinned, model, f_mf, full_cmd_line);
+      nc_data_cluster_ncount_print (dca_unbinned, model, f_mf, full_cmd_line);
       fprintf (f_mf, "\n\n");
     }
     fclose (f_mf);
