@@ -85,6 +85,8 @@ _ncm_fit_constructed (GObject *object)
   {
     NcmFit *fit = NCM_FIT (object);
     gint n = ncm_dataset_get_n (fit->lh->dset);
+    gint n_priors = ncm_likelihood_priors_length (fit->lh);
+    gint data_dof = ncm_dataset_get_dof (fit->lh->dset);
 
     g_assert (ncm_dataset_all_init (fit->lh->dset));
 
@@ -99,9 +101,9 @@ _ncm_fit_constructed (GObject *object)
      * 
      */
     {
-      guint data_len   = n + ncm_likelihood_priors_length (fit->lh);
+      guint data_len   = n + n_priors;
       guint fparam_len = ncm_mset_fparam_len (fit->mset);
-      gint dof         = data_len - fparam_len;
+      gint dof         = data_dof + n_priors - fparam_len;
 
       fit->fstate = ncm_fit_state_new (data_len, fparam_len, dof,
                                        NCM_FIT_GET_CLASS (fit)->is_least_squares);
@@ -229,9 +231,11 @@ _ncm_fit_reset (NcmFit *fit)
   ncm_mset_prepare_fparam_map (fit->mset);
   {
     guint n          = ncm_dataset_get_n (fit->lh->dset);
-    guint data_len   = n + ncm_likelihood_priors_length (fit->lh);
+    gint n_priors    = ncm_likelihood_priors_length (fit->lh);
+    guint data_len   = n + n_priors;
     guint fparam_len = ncm_mset_fparam_len (fit->mset);
-    gint dof         = data_len - fparam_len;
+    gint data_dof    = ncm_dataset_get_dof (fit->lh->dset);
+    gint dof         = data_dof - fparam_len;
 
     g_assert (ncm_dataset_all_init (fit->lh->dset));
     g_assert (data_len > 0);
@@ -817,7 +821,10 @@ ncm_fit_log_step (NcmFit *fit, gdouble m2lnL)
   if (fit->mtype == NCM_FIT_RUN_MSGS_FULL)
     ncm_fit_log_state (fit, m2lnL);
   else if (fit->mtype == NCM_FIT_RUN_MSGS_SIMPLE)
-    g_message (".");
+  {
+    if (fit->fstate->niter < 10 || ((fit->fstate->niter % 10) == 0))
+      ncm_message (".");
+  }
   return;
 }
 
@@ -1811,6 +1818,8 @@ ncm_fit_function_error (NcmFit *fit, NcmMSetFunc *func, gdouble z, gboolean pret
    g_message ("# % -12.4g +/- % -12.4g\n", NCM_FUNC_F(func, fit->mset, z), sqrt(result));
 
    ncm_fit_params_return_tmp_vector (fit->pt, tmp1);
+   
+   ncm_vector_free (v);
 
    return sqrt(result);
    */
