@@ -39,7 +39,14 @@
 
 #include "math/ncm_matrix.h"
 
-G_DEFINE_TYPE (NcmMatrix, ncm_matrix, G_TYPE_INITIALLY_UNOWNED);
+#if (defined HAVE_CLAPACK_H) && (defined HAVE_CLAPACK_DPOTRF)
+#include <clapack.h>
+#else
+#include <gsl/gsl_cblas.h>
+#include <gsl/gsl_linalg.h>
+#endif
+
+G_DEFINE_TYPE (NcmMatrix, ncm_matrix, G_TYPE_OBJECT);
 
 /**
  * ncm_matrix_new:
@@ -62,22 +69,6 @@ ncm_matrix_new (gsize nrows, gsize ncols)
   return cm;
 }
 
-/**
- * ncm_matrix_new_sunk:
- * @nrows: number of rows.
- * @ncols: number of columns.
- *
- * This function allocates memory for a new #NcmMatrix of doubles
- * with @nrows rows and @ncols columns. Returns a sunk reference.
- *
- * Returns: A new #NcmMatrix.
- */
-NcmMatrix *
-ncm_matrix_new_sunk (gsize nrows, gsize ncols)
-{
-  return ncm_matrix_ref (ncm_matrix_new (nrows, ncols));
-}
-
 /**
  * ncm_matrix_new_gsl: (skip)
  * @gm: matrix from GNU Scientific Library (GSL) to be converted into a #NcmMatrix.
@@ -247,8 +238,7 @@ ncm_matrix_get_submatrix (NcmMatrix *cm, gsize k1, gsize k2, gsize nrows, gsize
 {
   NcmMatrix *scm = g_object_new (NCM_TYPE_MATRIX, NULL);
   scm->mv = gsl_matrix_submatrix (NCM_MATRIX_GSL (cm), k1, k2, nrows, ncols);
-  scm->pobj = G_OBJECT (cm);
-  g_object_ref (cm);
+  scm->pobj = g_object_ref (cm); 
   scm->type = NCM_MATRIX_DERIVED;
 
   return scm;
@@ -271,8 +261,7 @@ ncm_matrix_get_col (NcmMatrix *cm, const gsize col)
   cv->vv = gsl_matrix_column (NCM_MATRIX_GSL (cm), col);
   cv->a = NULL;
   cv->type = NCM_VECTOR_DERIVED;
-  cv->pobj = G_OBJECT (cm);
-  g_object_ref (cm);
+  cv->pobj = g_object_ref (cm);
 
   return cv;
 }
@@ -294,8 +283,7 @@ ncm_matrix_get_row (NcmMatrix *cm, const gsize row)
   cv->vv = gsl_matrix_row (NCM_MATRIX_GSL (cm), row);
   cv->a = NULL;
   cv->type = NCM_VECTOR_DERIVED;
-  cv->pobj = G_OBJECT (cm);
-  g_object_ref (cm);
+  cv->pobj = g_object_ref (cm);
 
   return cv;
 }
@@ -311,8 +299,6 @@ ncm_matrix_get_row (NcmMatrix *cm, const gsize row)
 void
 ncm_matrix_free (NcmMatrix *cm)
 {
-  if (g_object_is_floating (cm))
-    g_object_ref_sink (cm);
   g_object_unref (cm);
 }
 
@@ -327,8 +313,6 @@ ncm_matrix_free (NcmMatrix *cm)
 void
 ncm_matrix_clear (NcmMatrix **cm)
 {
-  if (*cm != NULL && g_object_is_floating (*cm))
-    g_object_ref_sink (*cm);
   g_clear_object (cm);
 }
 
@@ -435,6 +419,31 @@ ncm_matrix_add_mul (NcmMatrix *cm, const gdouble alpha, NcmMatrix *b)
   }
 }
 
+/**
+ * ncm_matrix_cholesky_decomp: (skip)
+ * @cm: a #NcmMatrix.
+ *
+ * Calculates inplace the Cholesky decomposition for a symmetric positive
+ * definite matrix.
+ * 
+ */
+void 
+ncm_matrix_cholesky_decomp (NcmMatrix *cm)
+{
+  gint ret;
+#if (defined HAVE_CLAPACK_H) && (defined HAVE_CLAPACK_DPOTRF)
+  ret = clapack_dpotrf (CblasRowMajor, CblasLower, NCM_MATRIX_NROWS (cm), 
+                        NCM_MATRIX_DATA (cm), NCM_MATRIX_NROWS (cm));
+  if (ret < 0)
+    g_error ("ncm_matrix_cholesky_decomp[clapack_dpotrf]: invalid parameter %d", -ret);
+  else if (ret > 0)
+    g_error ("ncm_matrix_cholesky_decomp[clapack_dpotrf]: the leading minor of order %d is not positive definite", ret);
+#else /* Fall back to gsl cholesky */
+  ret = gsl_linalg_cholesky_decomp (NCM_MATRIX_GSL (cm));
+  NC_TEST_GSL_RESULT("ncm_matrix_cholesky_decomp[gsl_linalg_cholesky_decomp]", ret);
+#endif
+}
+
 /**
  * ncm_matrix_new_gsl_const: (skip)
  * @m: matrix from GNU Scientific Library (GSL).
@@ -537,6 +546,24 @@ ncm_matrix_add_mul (NcmMatrix *cm, const gdouble alpha, NcmMatrix *b)
  *
  * Returns: (transfer container) (element-type double): FIXME
  */
+/**
+ * ncm_matrix_fast_get:
+ * @cm: a #NcmMatrix.
+ * @ij: FIXME
+ *
+ * FIXME
+ *
+ * Returns: FIXME
+ */
+/**
+ * ncm_matrix_fast_set:
+ * @cm: a #NcmMatrix.
+ * @ij: FIXME
+ * @val: FIXME
+ *
+ * FIXME
+ *
+ */
 
 static void
 ncm_matrix_init (NcmMatrix *m)
