@@ -24,15 +24,18 @@
 
 #ifndef _NCM_MPSF_0F1_H
 #define _NCM_MPSF_0F1_H
-#include <string.h>
-#include <stdio.h>
+
+#include <glib.h>
+#include <glib-object.h>
+
+#ifndef NUMCOSMO_GIR_SCAN
 #include <gmp.h>
 #include <mpfr.h>
-#include <glib.h>
+#endif
 
 G_BEGIN_DECLS
 
-void ncm_mpsf_0F1 (mpq_t b, mpq_t x, mpfr_ptr res, mp_rnd_t rnd);
+void ncm_mpsf_0F1_q (mpq_t b, mpq_t x, mpfr_ptr res, mp_rnd_t rnd);
 void ncm_mpsf_0F1_d (gdouble b, gdouble x, mpfr_ptr res, mp_rnd_t rnd);
 gdouble ncm_sf_0F1 (gdouble b, gdouble x);
 
