@@ -467,43 +467,40 @@ _nc_data_cluster_ncount_resample (NcmData *data, NcmMSet *mset)
     //printf ("% 20.15g % 20.15g\n", zi_real, lnMi_real);
   }
   
-  if (ncount->lnM_true != NULL)
-    ncm_vector_free (ncount->lnM_true);
-  ncount->lnM_true = ncm_vector_ref (ncm_vector_new_array (lnM_true_array));
+  ncm_vector_clear (&ncount->lnM_true);
+  ncount->lnM_true = ncm_vector_new_array (lnM_true_array);
   g_array_unref (lnM_true_array);
 
-  if (ncount->z_true != NULL)
-    ncm_vector_free (ncount->z_true);
-  ncount->z_true = ncm_vector_ref (ncm_vector_new_array (z_true_array));
+  ncm_vector_clear (&ncount->z_true);
+  ncount->z_true = ncm_vector_new_array (z_true_array);
   g_array_unref (z_true_array);
 
-  if (ncount->z_obs != NULL)
-    ncm_matrix_free (ncount->z_obs);
-  ncount->z_obs = ncm_matrix_ref (ncm_matrix_new_array (z_obs_array, z_obs_len));
+  ncm_matrix_clear (&ncount->z_obs);
+  ncount->z_obs = ncm_matrix_new_array (z_obs_array, z_obs_len);
   g_array_unref (z_obs_array);
 
-  if (ncount->lnM_obs != NULL)
-    ncm_matrix_free (ncount->lnM_obs);
-  ncount->lnM_obs = ncm_matrix_ref (ncm_matrix_new_array (lnM_obs_array, lnM_obs_len));
+  ncm_matrix_clear (&ncount->lnM_obs);
+  ncount->lnM_obs = ncm_matrix_new_array (lnM_obs_array, lnM_obs_len);
   g_array_unref (lnM_obs_array);
 
   if (z_obs_params_len > 0)
   {
-    if (ncount->z_obs_params != NULL)
-      ncm_matrix_free (ncount->z_obs_params);
-    ncount->z_obs_params = ncm_matrix_ref (ncm_matrix_new_array (z_obs_params_array, z_obs_params_len));
+    ncm_matrix_clear (&ncount->z_obs_params);
+    ncount->z_obs_params = ncm_matrix_new_array (z_obs_params_array, z_obs_params_len);
     g_array_unref (z_obs_params_array);
   }
 
   if (lnM_obs_params_len > 0)
   {
-    if (ncount->lnM_obs_params != NULL)
-      ncm_matrix_free (ncount->lnM_obs_params);
-    ncount->lnM_obs_params = ncm_matrix_ref (ncm_matrix_new_array (lnM_obs_params_array, lnM_obs_params_len));
+    ncm_matrix_clear (&ncount->lnM_obs_params);
+    ncount->lnM_obs_params = ncm_matrix_new_array (lnM_obs_params_array, lnM_obs_params_len);
     g_array_unref (lnM_obs_params_array);
   }
 
   ncount->np = NCM_MATRIX_NROWS (ncount->z_obs);
+
+  //printf ("Generated %ld, Expected %10.5g\n", ncount->np, nc_cluster_abundance_n (cad, cosmo));
+  
   if (data->desc != NULL)
     g_free (data->desc);
 
@@ -827,6 +824,83 @@ nc_data_cluster_ncount_hist_lnM_z (NcmData *data, gsl_vector *lnM_nodes, gsl_vec
   return hist;
 }
 
+/**
+ * nc_data_cluster_ncount_print:
+ * @data: FIXME
+ * @cosmo: a NcHICosmo
+ * @out: FIXME
+ * @header: FIXME
+ *
+ * FIXME
+ *
+ */
+void
+nc_data_cluster_ncount_print (NcmData *data, NcHICosmo *cosmo, FILE *out, gchar *header)
+{
+  NcDataClusterNCount *ncount = NC_DATA_CLUSTER_NCOUNT (data);
+  NcClusterAbundance *cad = ncount->cad;
+  gint i, j;
+  gint nbins_M = 100;
+  gint nbins_z = 20;
+  gsl_vector *lnM_nodes = gsl_vector_alloc (nbins_M);
+  gsl_vector *z_nodes = gsl_vector_alloc (nbins_z);
+
+  for (i = 0; i < nbins_M; i++)
+  {
+    gdouble lnM = cad->lnMi + (cad->lnMf - cad->lnMi) / (nbins_M - 1.0) * i;
+    gsl_vector_set (lnM_nodes, i, lnM);
+
+    printf ("lnM = %5.5g Me = %5.5g M10 = %5.5g\n", gsl_vector_get (lnM_nodes, i), exp(gsl_vector_get (lnM_nodes, i)), pow(10, gsl_vector_get (lnM_nodes, i)));
+  }
+
+  for (j = 0; j < nbins_z; j++)
+  {
+    gdouble z = cad->zi + (cad->zf - cad->zi) / (nbins_z - 1.0) * j;
+    gsl_vector_set (z_nodes, j, z);
+
+    printf ("z = %5.5g\n", gsl_vector_get (z_nodes, j));
+  }
+
+  if (header != NULL)
+    fprintf (out, "# %s\n# ", header);
+  else
+    fprintf (out, "# ");
+
+  gsl_histogram2d *h = nc_data_cluster_ncount_hist_lnM_z (data, lnM_nodes, z_nodes);
+
+
+  fprintf (out, "# z M N/(logM * V) (catalog) dn/dlog10M (theory) Nmi(catalog)(abundance in bins of redshift and mass) Nmi(theory)\n");
+  for (j = 0; j < nbins_z - 1; j++)
+  {
+    gdouble zm, dz, zl, zu, V;
+    gsl_histogram2d_get_yrange (h, j, &zl, &zu);
+    zm = (zu + zl) / 2.0;
+    dz = (zu - zl);
+    V = nc_mass_function_dv_dzdomega (cad->mfp, cosmo, zm) * cad->mfp->area_survey * dz;
+    for (i = 0; i < nbins_M; i++)
+    {
+      gdouble ln_ml, ln_mu, Mm, lnMm, log_mu, log_ml;
+      gdouble Nmi = gsl_histogram2d_get (h, i, j);
+      gdouble dndlog10M, ca_M;
+      gsl_histogram2d_get_xrange (h, i, &ln_ml, &ln_mu);
+      lnMm = (ln_ml + ln_mu) / 2.0;
+      Mm = exp (lnMm);
+      log_mu = log10 (exp(ln_mu));
+      log_ml = log10 (exp(ln_ml));
+      dndlog10M = M_LN10 * nc_mass_function_dn_dlnm (cad->mfp, cosmo, lnMm, zm);
+      ca_M = (log_mu - log_ml) * V * dndlog10M;
+
+      //printf ("log-mu = %5.5g log-ml = %5.5g\n", log_mu, log_ml);
+      fprintf (out, "% 6.6g % 6.6e % 6.6g % 6.6g % 6.6g % 6.6g\n", zm, Mm, Nmi / ((log_mu - log_ml) * V), dndlog10M, Nmi, ca_M);
+    }
+    fprintf (out, "\n\n");
+  }
+
+  gsl_vector_free (lnM_nodes);
+  gsl_vector_free (z_nodes);
+  gsl_histogram2d_free (h);
+}
+
 #ifdef NUMCOSMO_HAVE_CFITSIO
 
 #define NC_FITS_ERROR(status) \
@@ -1020,7 +1094,7 @@ nc_data_cluster_ncount_catalog_load (NcmData *data, gchar *filename)
     NC_FITS_ERROR (status);
 
   if (hdutype != BINARY_TBL)
-    g_error ("%s (%d): Ncuster catalog is not binary!\n", __FILE__, __LINE__);
+    g_error ("%s (%d): NcDataClusterNCount catalog is not binary!\n", __FILE__, __LINE__);
 
   if (ncount->z != NULL)
     nc_cluster_redshift_free (ncount->z);
@@ -1092,13 +1166,11 @@ nc_data_cluster_ncount_catalog_load (NcmData *data, gchar *filename)
       g_error ("NcClusterMass object has observables length %d but fits has %ld.",
                nc_cluster_mass_obs_len (ncount->m), lnM_obs_rp);
 
-    if (ncount->z_obs)
-      ncm_matrix_free (ncount->z_obs);
-    ncount->z_obs = ncm_matrix_new_sunk (ncount->np, z_obs_rp);
+    ncm_matrix_clear (&ncount->z_obs);
+    ncount->z_obs = ncm_matrix_new (ncount->np, z_obs_rp);
 
-    if (ncount->lnM_obs)
-      ncm_matrix_free (ncount->lnM_obs);
-    ncount->lnM_obs = ncm_matrix_new_sunk (ncount->np, lnM_obs_rp);
+    ncm_matrix_clear (&ncount->lnM_obs);
+    ncount->lnM_obs = ncm_matrix_new (ncount->np, lnM_obs_rp);
 
     if (fits_read_col (fptr, TDOUBLE, z_obs_i, 1, 1, ncount->np, NULL, ncm_matrix_ptr (ncount->z_obs, 0, 0), NULL, &status))
       NC_FITS_ERROR(status);
@@ -1128,9 +1200,8 @@ nc_data_cluster_ncount_catalog_load (NcmData *data, gchar *filename)
         g_error ("NcClusterRedshift object has observable parameters length %d but fits has %ld.",
                  nc_cluster_redshift_obs_params_len (ncount->z), z_obs_params_rp);
 
-      if (ncount->z_obs_params)
-        ncm_matrix_free (ncount->z_obs_params);
-      ncount->z_obs_params = ncm_matrix_new_sunk (ncount->np, z_obs_params_rp);
+      ncm_matrix_clear (&ncount->z_obs_params);
+      ncount->z_obs_params = ncm_matrix_new (ncount->np, z_obs_params_rp);
 
       if (fits_read_col (fptr, TDOUBLE, z_obs_params_i, 1, 1, ncount->np, NULL, ncm_matrix_ptr (ncount->z_obs_params, 0, 0), NULL, &status))
         NC_FITS_ERROR(status);
@@ -1152,9 +1223,8 @@ nc_data_cluster_ncount_catalog_load (NcmData *data, gchar *filename)
         g_error ("NcClusterMass object has observable parameters length %d but fits has %ld.",
                  nc_cluster_mass_obs_params_len (ncount->m), lnM_obs_params_rp);
 
-      if (ncount->lnM_obs_params)
-        ncm_matrix_free (ncount->lnM_obs_params);
-      ncount->lnM_obs_params = ncm_matrix_new_sunk (ncount->np, lnM_obs_params_rp);
+      ncm_matrix_clear (&ncount->lnM_obs_params);
+      ncount->lnM_obs_params = ncm_matrix_new (ncount->np, lnM_obs_params_rp);
 
 
       if (fits_read_col (fptr, TDOUBLE, lnM_obs_params_i, 1, 1, ncount->np, NULL, ncm_matrix_ptr (ncount->lnM_obs_params, 0, 0), NULL, &status))
@@ -1164,29 +1234,21 @@ nc_data_cluster_ncount_catalog_load (NcmData *data, gchar *filename)
 
   {
     gint z_true_i, lnM_true_i;
-    if (ncount->z_true != NULL)
-    {
-      ncm_vector_free (ncount->z_true);
-      ncount->z_true = NULL;
-    }
+    
+    ncm_vector_clear (&ncount->z_true);
     if (!fits_get_colnum (fptr, CASESEN, "Z_TRUE", &z_true_i, &status))
     {
-      ncount->z_true = ncm_vector_new_sunk (ncount->np);
+      ncount->z_true = ncm_vector_new (ncount->np);
       if (fits_read_col (fptr, TDOUBLE, z_true_i, 1, 1, ncount->np, NULL, ncm_vector_ptr (ncount->z_true, 0), NULL, &status))
         NC_FITS_ERROR(status);
     }
     else
       status = 0;
 
-    if (ncount->lnM_true != NULL)
-    {
-      ncm_vector_free (ncount->lnM_true);
-      ncount->lnM_true = NULL;
-    }
-
+    ncm_vector_clear (&ncount->lnM_true);
     if (!fits_get_colnum (fptr, CASESEN, "LNM_TRUE", &lnM_true_i, &status))
     {
-      ncount->lnM_true = ncm_vector_new_sunk (ncount->np);
+      ncount->lnM_true = ncm_vector_new (ncount->np);
       if (fits_read_col (fptr, TDOUBLE, lnM_true_i, 1, 1, ncount->np, NULL, ncm_vector_ptr (ncount->lnM_true, 0), NULL, &status))
         NC_FITS_ERROR(status);
     }
