@@ -179,11 +179,11 @@
 #include <numcosmo/lss/nc_cluster_mass_benson.h>
 #include <numcosmo/lss/nc_cluster_mass_benson_xray.h>
 #include <numcosmo/lss/nc_cluster_abundance.h>
-#include <numcosmo/lss/read_matrix.h>
-#include <numcosmo/lss/print_data.h>
 
 /* Observable data */
+#include <numcosmo/nc_data_snia.h>
 #include <numcosmo/nc_data_dist_mu.h>
+#include <numcosmo/nc_data_snia_cov.h>
 #include <numcosmo/nc_data_hubble.h>
 #include <numcosmo/nc_data_bao_a.h>
 #include <numcosmo/nc_data_bao_dv.h>
