@@ -77,9 +77,6 @@ test_ncm_matrix_new_sanity (NcmMatrix *cm)
   guint i;
 
   g_assert (NCM_IS_MATRIX (cm));
-  g_assert (g_object_is_floating (cm));
-  ncm_matrix_ref (cm);
-  g_assert (!g_object_is_floating (cm));
 
   for (i = 0; i < 10 * _NCM_MATRIX_TEST_NROW; i++)
   {
@@ -389,9 +386,6 @@ test_ncm_matrix_submatrix (void)
   }
 
   g_assert (NCM_IS_MATRIX (sm));
-  g_assert (g_object_is_floating (sm));
-  ncm_matrix_ref (sm);
-  g_assert (!g_object_is_floating (sm));
 
   ncm_matrix_free (m);
   g_assert (G_IS_OBJECT (m));
